@@ -592,6 +592,10 @@ CREATE TABLE IF NOT EXISTS `auto_ussd` (
   `auto_ussd_step2_start_r` varchar(160) character set utf8 NOT NULL,
   `sms_report_goip` int(11) NOT NULL,
   `bal_delay` int(11) NOT NULL default '0',
+  `re_step2_enable` tinyint(1) NOT NULL,
+  `re_step2_cmd` varchar(64) NOT NULL,
+  `re_step2_ok_r` varchar(64) character set utf8 NOT NULL,
+  `auto_reset_remain_enable` tinyint(1) NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `prov_id` (`prov_id`,`goip_id`),
   KEY `recharge_ussd1_goip` (`recharge_ussd1_goip`),
